==> nextcloud-13.0.1.tgz: nextcloud/apps/survey_client/l10n/nl.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Gebruikersonderzoek",
    "Sent on: {on}" : "Verstuurd op: {on}",
    "An error occurred while sending your report." : "Er trad een fout op bij het versturen van je rapport",
    "App list <em>(for each app: name, version, enabled status)</em>" : "App lijst <em>(voor elke app: naam, versie, ingeschakeld?)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Database omgeving<em>(type, versie, database omvang)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Crypto informatie <em>(ingeschakeld?, wat is de standaardmodule)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Aantal shares <em>(per type en permissie-instelling)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP omgeving <em>(versie, geheugenlimiet, max. uitvoeringstijd, max. bestandsomvang)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Server details <em>(versie, memcache gebruikt, status van locking/previews/avatars)</em>",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "Statistieken <em>(aantal: bestanden, gebruikers, opslag per type, reacties en tags)</em>",
    "Help improve Nextcloud" : "Help Nextcloud verbeteren",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Wil je ons helpen om Nextcloud te verbeteren, door geanonimiseerde gegevens over je installatie en gebruik te delen? Je kunt dit altijd weer uit zetten bij de beheerdersinstellingen.",
    "Not now" : "Niet nu",
    "Send usage" : "Verstuur gebruik",
    "Never" : "Nooit",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Je kunt ons helpen Nextcloud te verbeteren door gegevens over je installatie en gebruik te delen.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "We nemen je privacy serieus. Het delen van deze data staat standaard uit en je moet zelf aangeven als je dit wél wilt delen. De gegevens worden eerst geanonimiseerd en je kunt kiezen welke data je wilt delen. Nadat we een rapport hebben ontvangen, wordt de vorige verwijderd. Upload een leeg rapport om alle data te wissen die nu op de server staat.",
    "Send new report now" : "Verstuur nu een nieuw rapport",
    "Send usage survey monthly" : "Verstuur maandelijks gebruiksrapport",
    "Data to send" : "Te versturen gegevens",
    "Last report" : "Laatste rapport",
    "Sent on: %s" : "Verstuurd op: %s",
    "App list <em>(for each app: name, version, is enabled?)</em>" : "App lijst <em>(voor elke app: naam, versie, ingeschakeld?)</em>",
    "Server instance details <em>(version, memcache used, locking/previews/avatars enabled?)</em>" : "Server details <em>(versie, memcache gebruikt, locking/previews/avatars ingeschakeld?)</em>",
    "You can help us to improve Nextcloud by sending us some data about your current setup and usage." : "Je kunt ons helpen Nextcloud te verbeteren door gegevens over je huidige installatie en gebruik te versturen.",
    "We take your privacy seriously. The data is anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data is sent and always see the last report sent to us. When the server receives a new report of your instance, all entries from previous reports are removed. If you disable one of the settings below, you can send a new report, which will delete the data that is currently stored on the server." : "We nemen je privacy serieus. De gegevens zijn geanonimiseerd en je kunt het op elk gewenst moment in- of uitschakelen. Standaard is het altijd uitgeschakeld. Hieronder kun je de type data aanpassen en het laatste rapport bekijken dat aan ons is gestuurd. Als je één van de onderstaande instellingen uitschakelt, kun je een nieuw rapport versturen. De gegevens die we eerder van je server hebben ontvangen, worden dan overschreven."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-14.0.1.tgz: nextcloud/apps/survey_client/l10n/nl.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Gebruikersonderzoek",
    "Last report sent on: {on}" : "Laatste rapportage verstuurd op: {on}",
    "An error occurred while sending your report." : "Er trad een fout op bij het versturen van je rapport",
    "App list <em>(for each app: name, version, enabled status)</em>" : "App lijst <em>(voor elke app: naam, versie, ingeschakeld?)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Database omgeving<em>(type, versie, database omvang)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Crypto informatie <em>(ingeschakeld?, wat is de standaardmodule)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Aantal shares <em>(per type en permissie-instelling)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP omgeving <em>(versie, geheugenlimiet, max. uitvoeringstijd, max. bestandsomvang)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Server details <em>(versie, memcache gebruikt, status van locking/previews/avatars)</em>",
    "Help improve Nextcloud" : "Help Nextcloud verbeteren",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Wil je ons helpen om Nextcloud te verbeteren, door geanonimiseerde gegevens over je installatie en gebruik te delen? Je kunt dit altijd weer uit zetten bij de beheerdersinstellingen.",
    "Not now" : "Niet nu",
    "Send usage" : "Verstuur gebruik",
    "Never" : "Nooit",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Je kunt ons helpen Nextcloud te verbeteren door gegevens over je installatie en gebruik te delen.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "We nemen je privacy serieus. Het delen van deze data staat standaard uit en je moet zelf aangeven als je dit wél wilt delen. De gegevens worden eerst geanonimiseerd en je kunt kiezen welke data je wilt delen. Nadat we een rapport hebben ontvangen, wordt de vorige verwijderd. Upload een leeg rapport om alle data te wissen die nu op de server staat.",
    "Send new report now" : "Verstuur nu een nieuw rapport",
    "Send usage survey monthly" : "Verstuur maandelijks gebruiksrapport",
    "Data to send" : "Te versturen gegevens",
    "Last report sent on: %s" : "Laatste reportage verstuurd op %s",
    "Last report" : "Laatste rapport",
    "Sent on: {on}" : "Verstuurd op: {on}",
    "App list <em>(for each app: name, version, is enabled?)</em>" : "App lijst <em>(voor elke app: naam, versie, ingeschakeld?)</em>",
    "Server instance details <em>(version, memcache used, locking/previews/avatars enabled?)</em>" : "Server details <em>(versie, memcache gebruikt, locking/previews/avatars ingeschakeld?)</em>",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "Statistieken <em>(aantal: bestanden, gebruikers, opslag per type, reacties en tags)</em>",
    "You can help us to improve Nextcloud by sending us some data about your current setup and usage." : "Je kunt ons helpen Nextcloud te verbeteren door gegevens over je huidige installatie en gebruik te versturen.",
    "We take your privacy seriously. The data is anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data is sent and always see the last report sent to us. When the server receives a new report of your instance, all entries from previous reports are removed. If you disable one of the settings below, you can send a new report, which will delete the data that is currently stored on the server." : "We nemen je privacy serieus. De gegevens zijn geanonimiseerd en je kunt het op elk gewenst moment in- of uitschakelen. Standaard is het altijd uitgeschakeld. Hieronder kun je de type data aanpassen en het laatste rapport bekijken dat aan ons is gestuurd. Als je één van de onderstaande instellingen uitschakelt, kun je een nieuw rapport versturen. De gegevens die we eerder van je server hebben ontvangen, worden dan overschreven.",
    "Sent on: %s" : "Verstuurd op: %s"
},
"nplurals=2; plural=(n != 1);");
